@@ -43,10 +43,14 @@ TZ_CHOICES = [(float(x[0]), x[1]) for x in (
 (11.5, '+11.5'), (12, '+12'), (13, '+13'), (14, '+14'),
 )]
 
-MARKUP_CHOICES = [(i, i) for i in defaults.PYBB_MARKUP_ENGINES.keys()]
-
 #noinspection PyUnusedLocal
 def get_file_path(instance, filename):
+    """
+    This function generate filename with uuid4
+    it's useful if:
+    - you don't want to allow others to see original uploaded filenames
+    - users can upload images with unicode in filenames wich can confuse browsers and fs
+    """
     ext = filename.split('.')[-1]
     filename = "%s.%s" % (uuid.uuid4(), ext)
     return os.path.join('pybb/avatar', filename)
@@ -54,7 +58,9 @@ def get_file_path(instance, filename):
 class Category(models.Model):
     name = models.CharField(_('Name'), max_length=80)
     position = models.IntegerField(_('Position'), blank=True, default=0)
-    hidden = models.BooleanField(_('Hidden'), blank=False, null=False, default=False)
+    hidden = models.BooleanField(_('Hidden'), blank=False, null=False, default=False,
+        help_text = _('If checked, this category will be visible only for staff')
+    )
 
     class Meta(object):
         ordering = ['position']
@@ -154,9 +160,14 @@ class Topic(models.Model):
 
     @property
     def head(self):
+        """
+        Get first post and cache it for request
+        """
         if not hasattr(self, "_head"):
-            self._head = self.posts.all().order_by('created')[0]
-        return self._head
+            self._head = self.posts.all().order_by('created')
+        if not len(self._head):
+            return None
+        return self._head[0]
 
     def get_last_post(self):
         return self.posts.order_by('-created').select_related()[0]
@@ -187,17 +198,13 @@ class RenderableItem(models.Model):
     class Meta(object):
         abstract = True
 
-    markup = models.CharField(_('Markup'), max_length=15, default=defaults.PYBB_DEFAULT_MARKUP, choices=MARKUP_CHOICES)
     body = models.TextField(_('Message'))
     body_html = models.TextField(_('HTML version'))
     body_text = models.TextField(_('Text version'))
 
     def render(self):
-        if self.markup in defaults.PYBB_MARKUP_ENGINES:
-            self.body_html = defaults.PYBB_MARKUP_ENGINES[self.markup](self.body)
-        else:
-            raise Exception('Invalid markup property: %s' % self.markup)
-            # Remove tags which was generated with the markup processor
+        self.body_html = defaults.PYBB_MARKUP_ENGINES[defaults.PYBB_MARKUP](self.body)
+        # Remove tags which was generated with the markup processor
         text = strip_tags(self.body_html)
         # Unescape entities which was generated with the markup processor
         self.body_text = unescape(text)
@@ -255,30 +262,36 @@ class Post(RenderableItem):
 
 
 class PybbProfile(models.Model):
-    '''
-        Abstract class for user profile, site profile should be inherted from this class
-    '''
+    """
+    Abstract class for user profile, site profile should be inherted from this class
+    """
+
     class Meta(object):
         abstract = True
         permissions = (
             ("block_users", "Can block any user"),
         )
 
-    signature = models.TextField(_('Signature'), blank=True, max_length=defaults.PYBB_SIGNATURE_MAX_LENGTH)
+    signature = models.TextField(_('Signature'), blank=True,
+        max_length=defaults.PYBB_SIGNATURE_MAX_LENGTH)
     signature_html = models.TextField(_('Signature HTML Version'), blank=True,
-                                      max_length=defaults.PYBB_SIGNATURE_MAX_LENGTH + 30)
-    time_zone = models.FloatField(_('Time zone'), choices=TZ_CHOICES, default=float(defaults.PYBB_DEFAULT_TIME_ZONE))
-    language = models.CharField(_('Language'), max_length=10, blank=True, choices=settings.LANGUAGES, default=dict(settings.LANGUAGES)[settings.LANGUAGE_CODE.split('-')[0]])
-    show_signatures = models.BooleanField(_('Show signatures'), blank=True, default=True)
-    markup = models.CharField(_('Default markup'), max_length=15, default=defaults.PYBB_DEFAULT_MARKUP,
-                              choices=MARKUP_CHOICES)
+        max_length=defaults.PYBB_SIGNATURE_MAX_LENGTH + 30)
+    time_zone = models.FloatField(_('Time zone'), choices=TZ_CHOICES,
+        default=float(defaults.PYBB_DEFAULT_TIME_ZONE))
+    language = models.CharField(_('Language'), max_length=10, blank=True,
+        choices=settings.LANGUAGES,
+        default=dict(settings.LANGUAGES)[settings.LANGUAGE_CODE.split('-')[0]])
+    show_signatures = models.BooleanField(_('Show signatures'), blank=True,
+        default=True)
     post_count = models.IntegerField(_('Post count'), blank=True, default=0)
-    avatar = ImageField(_('Avatar'), blank=True, null=True, upload_to=get_file_path)
-
-    autosubscribe = models.BooleanField(_('Automatically subscribe'), help_text=_('Automatically subscribe to topics that you answer'), default=defaults.PYBB_DEFAULT_AUTOSUBSCRIBE)
+    avatar = ImageField(_('Avatar'), blank=True, null=True,
+        upload_to=get_file_path)
+    autosubscribe = models.BooleanField(_('Automatically subscribe'),
+        help_text=_('Automatically subscribe to topics that you answer'),
+        default=defaults.PYBB_DEFAULT_AUTOSUBSCRIBE)
 
     def save(self, *args, **kwargs):
-        self.signature_html = defaults.PYBB_MARKUP_ENGINES[self.markup](self.signature)
+        self.signature_html = defaults.PYBB_MARKUP_ENGINES[defaults.PYBB_MARKUP](self.signature)
         super(PybbProfile, self).save(*args, **kwargs)
 
     @property
@@ -290,6 +303,10 @@ class PybbProfile(models.Model):
 
 
 class Profile(PybbProfile):
+    """
+    Profile class that can be used if you doesn't have
+    your site profile.
+    """
     user = AutoOneToOneField(User, related_name='pybb_profile', verbose_name=_('User'))
 
     class Meta(object):
@@ -339,9 +356,9 @@ class Attachment(models.Model):
 
 
 class TopicReadTracker(models.Model):
-    '''
+    """
     Save per user topic read tracking
-    '''
+    """
     class Meta(object):
         verbose_name = _('Topic read tracker')
         verbose_name_plural = _('Topic read trackers')
@@ -351,9 +368,9 @@ class TopicReadTracker(models.Model):
     time_stamp = models.DateTimeField(auto_now=True)
 
 class ForumReadTracker(models.Model):
-    '''
+    """
     Save per user forum read tracking
-    '''
+    """
     class Meta(object):
         verbose_name = _('Forum read tracker')
         verbose_name_plural = _('Forum read trackers')
